package org.eclipse.jdt.internal.compiler.apt.dispatch;

package .tmp;

import java.io.IOException;
import java.io.Writer;
import org.eclipse.jdt.internal.compiler.apt.dispatch.HookedJavaFileObject;

class ForwardingWriter extends Writer {
  private final Writer _w;
  
  ForwardingWriter(Writer w) {
    this._w = w;
  }
  
  public Writer append(char c) throws IOException {
    return this._w.append(c);
  }
  
  public Writer append(CharSequence csq, int start, int end) throws IOException {
    return this._w.append(csq, start, end);
  }
  
  public Writer append(CharSequence csq) throws IOException {
    return this._w.append(csq);
  }
  
  public void close() throws IOException {
    this._w.close();
    HookedJavaFileObject.this.closed();
  }
  
  public void flush() throws IOException {
    this._w.flush();
  }
  
  public void write(char[] cbuf) throws IOException {
    this._w.write(cbuf);
  }
  
  public void write(int c) throws IOException {
    this._w.write(c);
  }
  
  public void write(String str, int off, int len) throws IOException {
    this._w.write(str, off, len);
  }
  
  public void write(String str) throws IOException {
    this._w.write(str);
  }
  
  public void write(char[] cbuf, int off, int len) throws IOException {
    this._w.write(cbuf, off, len);
  }
  
  protected Object clone() throws CloneNotSupportedException {
    return new ForwardingWriter(this._w);
  }
  
  public int hashCode() {
    return this._w.hashCode();
  }
  
  public boolean equals(Object obj) {
    if (this == obj)
      return true; 
    if (obj == null)
      return false; 
    if (getClass() != obj.getClass())
      return false; 
    ForwardingWriter other = (ForwardingWriter)obj;
    if (this._w == null) {
      if (other._w != null)
        return false; 
    } else if (!this._w.equals(other._w)) {
      return false;
    } 
    return true;
  }
  
  public String toString() {
    return "ForwardingWriter wrapping " + this._w.toString();
  }
}
